NIDM-Results export
===================

Export of neuroimaging statistical results using the NeuroImaging Data
Model (`NIDM Results`_).

.. _NIDM Results: http://nidm.nidash.org/specs/nidm-results.html